@@ -22,9 +22,10 @@ def get_config_file(root: str) -> Optional[str]:
 
 
 def locate_config() -> Optional[str]:
-    conf = get_config_file(os.path.dirname(__file__))
+    conf = get_config_file(os.path.dirname(os.path.dirname(__file__)))
     return (
-        conf if os.path.exists(conf)
+        conf
+        if os.path.exists(conf)
         else get_config_file(os.environ.get(ENV_HOME, os.path.expanduser("~")))
     )
 
